* ### 6 Useful Stata Commands ###
* ###############################

*** Outline

* # 6. Useful Stata Commands
* # 6.1 margins, marginsplot; test & ttest
* # 6.2 estimates store & estout; outreg2
* # 6.3 rego

version 12.1
clear
set more off

cd "T:\Labor_economics\ES\ES6\Datasets_Internet"

* ###############################################
* ### 6.1 margins, marginsplot, test, & ttest ###

*  obtaining margins of responses

** margins, marginsplot

* One may want to estimate how much difference it makes if an x-variable is higher or lower by some amount. 
// The difference made is a function of the values of any other regressors.

/* "margins" is a postestimation command, a command for use after you have fit a model 
using an estimation command such as regress or logistic, or using almost any other estimation command.

Margins are statistics calculated from predictions of a previously fit model at fixed values of some covariates 
and averaging or otherwise integrating over the remaining covariates.

The "margins" command estimates margins of responses for specified values of covariates and presents the results as a table.

Capabilities include estimated marginal means, least-squares means, average and conditional marginal and partial effects 
(which may be reported as derivatives or as elasticities), average and conditional adjusted predictions, and predictive margins.

What we call margins of responses are also known as predictive margins, adjusted predictions, and recycled predictions. 
When applied to balanced data, margins of responses are also called estimated marginal means and least-squares means.

* # "margins" after "regress"

[based on Hamilton L. C. (2013). Statistics with STATA: Version 12, 8th Edition. Cengage. University of New Hampshire, Ch. 7]

Consider dataset Nations2.dta, which contains U.N. human-development indicators for 194 countries: */

use T:\Labor_economics\ES\ES6\Datasets\Nations2.dta, clear

describe country region life school chldmort adfert gdp
summarize life school chldmort adfert gdp

* # Predictive margins and adjusted predictions examples

* Simple regression

regress life school

/* Mean years of schooling among these nations range from 1.15 to 12.7. 
What mean life expectancies does our model predict for nations with, for example, 2 or 12 years of schooling?
The margins command offers a quick way to view predicted means along with their confidence intervals, 
and z tests (which often are not interesting) for whether those means differ from zero.
A vertical squish vsquish option reduces the number of blank lines between rows in the table. */

margins, at(school = (2 12)) vsquish

/* For the hypothetical possibility in which for all observations school = 2, 
predicted mean life expectancy equals 55.26 years, 
with a confidence interval from 53.19 to 57.34. 
At school = 12, predicted mean life expectancy is 79.78 years 
with an interval from 77.97 to 81.59. 

Standard errors are obtained by the delta method, at least by default. The delta method assumes
that the values at which the covariates are evaluated to obtain the marginal responses are fixed.

We could obtain predicted means of life expecting for school values at 1-year intervals from 2 through 12, 
and graph the results, by typing two commands: */

margins, at(school = (2(1)12)) vsquish
marginsplot

* Multiple regression

generate loggdp = log10(gdp)
regress life loggdp chldmort

/* We could calculate predicted values for any combination of loggdp and chldmort 
by substituting those values into the regression equation. 
The margins command obtains predicted means (also called adjusted means) of the dependent variable 
at specified values of one or more independent variables. 

For example, to see the predicted mean life expectancy, adjusted for loggdp, at chldmort values of 2, 100 and 200: */

margins, at(chldmort = (2 100 200)) vsquish

/* This margins table tells us that the predicted mean life expectancy, 
at chldmort = 2 across all observed values of loggdp, is 75.23. 
Similarly, the predicted mean life expectancy at chldmort = 200 is 46.37. 

If we include the "atmeans" option, loggpd would be set to its mean 
(hence we would use the mean values of the other regressors instead of the actual values)  
giving an equivalent result in this instance.
The output would then be labeled adjusted predictions instead of predictive margins.

We could also ask for predicted means for specified values of both chldmort and loggdp. 
The following commands request means at six combinations of values: 
chldmort at 2, 100 or 200, and loggdp at 2.5 or 4.5. */

margins, at(chldmort = (2 100 200) loggdp = (2.5 4.5)) vsquish

* The follow-up command marginsplot graphs margins results:

marginsplot

** test

/* [test -- Test linear hypotheses after estimation
	testnl -- Test nonlinear hypotheses after estimation
	ttest -- Mean-comparison tests] */

regress life school loggdp adfert chldmort

test adfert chldmort

/* While the individual null hypotheses point in opposite directions (effect of chldmort significant, adfert not),
the joint hypothesis that coefficients on chldmort and adfert both equal zero can reasonably be rejected (p < .00005). 
Such tests on subsets of coefficients are useful when we have several conceptually related predictors 
or when individual coefficient estimates appear unreliable due to multicollinearity.

test could duplicate the overall F test: */

test school loggdp adfert chldmort

/* For example, the F statistic obtained by test equals the square of the t statistic in the regression table, 
2.25 = (1.50)^2, and yields exactly the same p-value: */

test school

/* Applications of test, more useful in advanced work (although not meaningful for the lifeexpectancy example at hand), 
include the following.

1. Test whether a coefficient equals a specified constant. 
For example, to test the null hypothesis that the coefficient on school equals 1 (H0: beta1 = 1), 
instead of testing the usual null hypothesis that it equals 0 (H0: beta1 = 0), type: */

test school = 1

/* 2. Test whether two coefficients are equal. 
For example, the following command evaluates the null hypothesis H0: beta2 = beta3: */

test loggdp = adfert

/* 3. Finally, test understands some linear algebraic expressions. 
We could request something like the following, which would test H0: beta2 = (beta3 + beta4) / 100 */

test school = (loggdp + adfert)/100

* Consult help test for more information and examples.

** Dummy Variables and ttest

/* Categorical variables can become predictors in a regression when they are expressed as 
one or more {0,1} dichotomies called dummy variables. 

For example, there are large regional differences in life expectancies. 
The categorical variable region takes values from 1 (Africa) to 5 (Oceania) 
which can be re-expressed as a set of five {0,1} dummy variables. 

The tabulate command offers an automatic way to do this, 
generating one dummy variable for each category of the tabulated variable 
when we include a gen (generate) option.
In the example below the resulting dummy variables are named reg1 through reg5. 
reg1 equals 1 for African nations and 0 for others; reg2 equals 1 for the Americas and 0 for others; 
and so forth. */

tabulate region, gen(reg)
describe reg*

label values reg1 reg1
label define reg1 0 "others" 1 "Africa"
tabulate reg1 region

/* Regressing life on one dummy variable, reg1 (Africa), is equivalent to performing a two-sample t test 
of whether mean life is the same across categories of reg1. 
Is the mean life expectancy significantly different, comparing Africa with other parts of the world? */

ttest life, by(reg1)

* if |t|<1.96 -- cannot reject H0

regress life reg1

/* The t test confirms that the 16.72-year difference between means for Africa (56.49) and other regions (73.21)
is statistically significant (t = 15.17, p = .000). 
We get exactly the same result from the dummy variable regression (t = 15.17, p = .000), 
where the coefficient reg1 (b1 = 16.72) likewise indicates that mean life expectancy is 16.72 years lower in Africa 
than in other regions (b0 = 73.21). */

** Interaction Effects

/* The previous section described what are called intercept dummy variables, because their
coefficients amount to shifts in a regression equations y intercept, comparing the 0 and 1 groups. 
Another use for dummy variables is to form interaction terms called slope dummy variables 
by multiplying a dummy times a measurement variable. 

In this section we stay with the Nations2.dta data, but consider some different variables: 
per capita carbon dioxide emissions (co2), percent of the population living in urban areas (urban), 
and the dummy variable reg4 defined as 1 for European countries and 0 for all others. 
We start out by labeling the values of reg4, and calculating a log version of co2 
because of that variables severe positive skew. */

label values reg4 reg4
label define reg4 0 "others" 1 "Europe"
generate logco2 = log10(co2)
label variable logco2 "log10(per cap CO2)"
describe urban reg4 co2 logco2

/* We form an interaction term or slope dummy variable named urb_reg4 
by multiplying the dummy variable reg4 times the measurement variable urban. 
The resulting variable urb_reg4 equals urban for countries in Europe, and zero for all other countries. */

generate urb_reg4 = urban * reg4
label variable urb_reg4 "interaction urban*reg4 (Europe)"

/* Regressing logco2 on urban, reg4 and the interaction term urb_reg4 gives a model that tests
whether either the y-intercept or the slope relating logco2 to urban might be different for Europe
compared with other regions. */

regress logco2 urban reg4 urb_reg4

/* The interaction effect is statistically significant (p = .043), suggesting that the relationship
between percent urban and log CO2 emissions is different for Europe than for the rest of the world. 
The main effect of urban is positive (.0217), meaning that logco2 tends to be higher in countries 
with more urbanized population. But the interaction coefficient is negative, 
meaning that this upward slope is less steep for Europe. */

/* The post-regression command "predict newvar" generates a new variable 
holding predicted values from the recent regression. 
Graphing the predicted values for this example visualizes our interaction effect. 
The line in the left-hand (reg4 = 0) panel has a slope of .0217 and y-intercept .4682. 
The line in the right panel (reg4 = 1) has a less-steep slope (.0084 = .0217385 - .0133405) 
and a higher y-intercept (.826 = - .4682452 + 1.294163). 
No European countries exhibit the low-urbanization, low-CO2 profile seen in other parts of the world; 
and even European nations with middling urbanization have relatively high CO2 emissions. */

predict co2hat
graph twoway scatter logco2 urban, msymbol(Oh) ///
|| connect co2hat urban, msymbol(+) ///
|| , by(reg4)

/* There is an alternative way to include interactions. 
The symbol # (pronounced cross) specifies an interaction between two variables, 
and ## a factorial interaction which automatically includes all the lower-level interactions involving those variables. 

The i.black and i.female notation tells Stata that black and female are categorical variables rather than continuous. 
i.group is called a factor variabl. When you type i.group, it forms the indicators for the unique values of group.
The use of # implies the i.prefix, i.e. unless you indicate otherwise Stata will assume 
that the variables on both sides of the # operator are categorical and will compute interaction terms accordingly.
Hence, we use the c.notation to override the default and tell Stata that age is a continuous variable.
So, c.age#c.age tells Stata to include age^2 in the model; we do not want or need to compute the variable separately.
By doing it this way, Stata knows that if age = 70, then age^2 = 4900, and it hence computes the predicted values correctly.

reg4 is an indicator variable and urban is continuous, so the same model estimated above could be obtained by the command: */

regress logco2 c.urban i.reg4 c.urban#i.reg4

* or equivalently with a factor interaction,

regress logco2 c.urban##i.reg4

/* "margins" understands # or ## interactions. 
Percent urban ranges from about 10 to 100 percent in these data, so we could graph the interaction as follows. 
First calculate the predicted means of logco2 at several combinations of urban (10, 40, 70 or 100) and reg4 (0 or 1). */

margins, at(urban = (10(30)100) reg4 = (0 1)) vsquish

/* Next, use "marginsplot" to graph these means. 
Note the use of twoway-type options to label details of the graph. 
The following Figure visualizes the same model as the previous Figure, 
but in a different style that shows confidence intervals for the predicted means instead of data points. 
The option in the following marginsplot command specifies l2 (letter el 2), a second left-hand axis title. */

marginsplot, l2("Log{subscript:10}(CO{subscript:2} per capita)") xlabel(10(30)100)

/* Interaction effects could also involve two measurement variables. 
A trick called centering helps to reduce multicollinearity problems with such interactions, 
and makes their main effects easier to interpret. 
Centering involves subtracting their respective means from both variables 
before defining an interaction term as their product.
Centered variables have means approximately equal to zero, and are negative for below-average values. 
The commands below calculate centered versions of urban and loggdp, named urban0 and loggdp0. 
The interaction term urb_gdp is then defined as the product of urban0 times loggdp0. */

summarize urban loggdp

generate urban0 = urban - 55.4
label variable urban0 "Percent urban, centered"
generate loggdp0 = loggdp - 3.78
label variable loggdp0 "log10(GDP per cap), centered"
generate urb_gdp = urban0 * loggdp0
label variable urb_gdp "interaction urban0*loggdp0"

* More precise centering could be performed using means returned by summarize:

summarize urban
generate urban00 = urban - r(mean)

/* We might also set aside all observations with missing values on any variables in the regression,
before obtaining a mean for centering.

Regressing logco2 on the centered main effects loggdp0 and urban0, along with the interaction term urb_gdp, 
we find that the interaction effect is negative and statistically significant. */

regress logco2 loggdp0 urban0 urb_gdp

/* The same regression could have been conducted, 
and the continuous-by-continuous variable interaction effect graphed, with the following three commands. */

regress logco2 c.loggdp0 c.urban0 c.loggdp0#c.urban0
margins, at(loggdp0 = (-1.3 1.1) urban0 =( -45 45))
marginsplot

/* Main effects in a regression of this sort, where the interacting variables have been centered, can
be interpreted as the effect of each variable when the other is at its mean. Thus, predicted logco2
rises by 1.12 with each 1-unit increase in loggdp, when urban is at its mean. Similarly, predicted
logco2 rises by only a small amount, .0025, with each 1-unit increase in urban when loggdp is
at its mean. The coefficient on interaction term urb_gdp, however, tells us that with each 1-unit
increase in urbanization, the effect of loggdp on logco2 becomes weaker, decreasing by .008.
That is, CO2 emissions increase as wealth increases, but do so less steeply in more urbanized
countries. */

* # "margins" after "logistic"

* [based on Hamilton L. C. (2013). Statistics with STATA: Version 12, 8th Edition. Cengage. University of New Hampshire, Ch. 7]

* logistic y x1 x2 x3

/* Performs logistic regression of {0,1} variable y on predictors x1, x2 and x3. 
Predictor variable effects are reported as odds ratios. 
A closely related command, logit, performs essentially the same analysis, 
but reports effects as log-odds regression coefficients. 
The underlying models fit by logistic and logit are the same, 
so predictions and diagnostic tests will be identical.

The first example, shuttle.dta, involves historical data covering the first 25 flights of the U.S. space shuttle. 
These data contain evidence that, if properly analyzed, might have persuaded NASA officials not to launch 
Challenger on its fatal flight in 1985 (the 25th shuttle flight, designated STS 51-L). 
The data are drawn from the Report of the Presidential Commission on the Space Shuttle Challenger Accident (1986) and from Tufte (1997). 
Tuftes book contains an excellent discussion about data and analytical issues. 
His comments regarding specific shuttle flights are included as a string variable in these data. */

use T:\Labor_economics\ES\ES6\Datasets\shuttle.dta, clear
describe

generate date = mdy(month, day, year)
format %td date

generate any = distress
replace any = 1 if distress == 2

/* Plotting the adjusted marginal or conditional effects helps to understand and communicate 
what a logistic model implies about probabilities.
 
For example, we could find the predicted probability of any thermal distress incidents as a function of temp, 
holding date constant at relatively low (early) and high (late) values. */

summarize date temp

/* Elapsed dates in these data range from the first shuttle flight on April 12, 1981 (date = 7772)
to the fatal Challenger launch on January 21, 1986 (date = 9524). 
Joint temperatures range from 31 to 81 degrees Fahrenheit. 
margins can calculate and marginsplot graph the predicted probabilities from our logistic model 
at 10-degree increments in temperature, at the earliest and latest dates. */

quietly logistic any date temp
margins, at(temp = (30(10)80) date = (7772 9524)) vsquish

marginsplot

/* The default marginsplot graph in the Figure conveys basic information, but is not pretty. 
For a more publishable version we could suppress the confidence intervals (noci), relocate the legend, 
use plot#opts() to visually distinguish the two curves, and add a title. 
First, we run margins again with one-degree increments in temperature, which will make the resulting curves smoother. */

quietly margins, at(temp = (30(1)80) date = (8000 9500))
marginsplot, noci legend(position(7) ring(0) rows(2)) ///
plot1opts(msymbol(i) lpattern(dash) lwidth(medthick)) ///
plot2opts(msymbol(i) lpattern(solid) lwidth(medthich)) ///
title("Predicted probability of booster O-ring damage")

/* According to our logistic model, around the time of the earliest shuttle flight (dashed curve in the Figure) 
the probability of thermal distress goes from near zero at 80 F, to near one below 40 F. 
By the time of the Challenger flight (solid curve), however, the probability of any distress exceeds .6 even in warm weather, 
and climbs toward one on flights below 70 F. 
Note that Challengers actual temperature at launch, 31 F, would place it at top left in the Figure. */

* obtaining marginal effects

/* "margins" has the same syntax when used with derivatives of responses as when used with responses.
To obtain derivatives, one specifies the dydx() option. 
If we wanted to examine the response variable dy=d(tmt), we would specify margins dydx(tmt) option. */

use margex.dta, clear
describe
logistic outcome treatment##group age c.age#c.age treatment#c.age

* Average marginal effect (partial effects) of one covariate

margins, dydx(treatment)

* The average marginal effect of treatment on the probability of a positive outcome is 0.039.

* Average marginal effects of all covariates:

margins, dydx(*) /* or margins, dydx(_all) */

* Marginal effects evaluated over the response surface
/* What follows maps out the entire response surface of our fitted model. 
We report the marginal effect of treatment evaluated at age = 20; 30; : : : ; 60, by each level of group. */

margins group, dydx(treatment) at(age=(20(10)60))

	
*** returt, ereturn

/* Commands often return results that can be used by programs you might write. 
To see a list of the results from the most recent command that returned results, type:
"return list" - shows returned results from a general command, like summarize.
"ereturn list" - shows returned results from an estimation command, like regress. */

* #############################################
* ### 6.2 estimates store & estout; outreg2 ###

* To install estout
*"findit estout" or "ssc install estout"

/* estout assembles a table of coefficients, "significance stars", summary statistics, standard errors, t- or z-statistics, p-values, 
confidence intervals, and other statistics for one or more models previously fitted and stored by "estimates store" or "eststo". */

* [based on http://www.soz.unibe.ch/content/ueber_uns/jann/publications/e19610/e20677/files20680/estout.pdf]

* Consider the following basic syntax, which includes only the most important options:

* estout [namelist] [using filename] [, cells(array) stats(scalarlist) style(style) options]

/* namelist provides the names of the stored estimation sets to be tabulated. 
You may use the * (to refer to all stored estimates) and ? wildcards in namelist. 
The results estimated last may be indicated by a period (.), even if they have not yet been stored. 
If no model is specified, estout tabulates the estimation sets stored by "eststo" (see help "eststo") or, 
if no such estimates are present, the currently active estimates (i.e. the model fit last).  
estout may be used after any estimation command that returns its results in e(). 

The default for estout is to produce a plain table containing point estimates. 
Producing a fully formatted end-product may involve specifying many options. 
However, note that a simple-to-use estout wrapper producing pre-formatted publication style tables is available as "esttab". 
Furthermore, use "estadd" to make additional results available for tabulation 
(such as the standardized coefficients or the means and standard deviations of the regressors) 
and "estpost" to tabulate results from non-estimation commands such as summarize or tabulate.

Commands/Programms similar to "estout" include "eststo", "esttab", "outreg", "outreg2", "modltbl", "mktab", "outtex", or "est2tex".
 
The cells() and stats() options determine the primary contents of the table. 
The style() option determines the basic formatting of the table. */

* [based on http://www.ats.ucla.edu/stat/stata/faq/estout.htm]

/* This section illustrates the "estout" command that makes regression tables in a format that is commonly used in journal articles.

Let's illustrate use of the estout command using the high school and beyond data file. */

use hsb2.dta, clear
describe

/* We will run 3 regression models predicting the variable read.  
The first model will predict from the variables female and write; 
the second model will predict from female, write and math; 
and the third model will predict from female, write, math, science and socst. 

After each regress we will run an "estimates store" command. 
We will then use estout to create a single table that will summarize these models side by side. */

regress read female write
estimates store m1, title(Model 1)

regress read female write math
estimates store m2, title(Model 2)

regress read female write math science socst
estimates store m3, title(Model 3)

estout m1 m2 m3

/* Now we have a perfectly fine table that just includes the regression coefficients. 
We will modify the estout command to add standard errors and stars for statistical significance. 
We will also format the output so that coefficients will have three decimal places and the standard errors to two decimal places. 
Note, the par option for "se" places parentheses around the standard error. */

estout m1 m2 m3, cells(b(star fmt(3)) se(par fmt(2)))

/* The table is better now, but it can be improved further by putting the model names above the columns, 
adding a legend and by changing the label for "_cons" to "constant." */

estout m1 m2 m3, cells(b(star fmt(3)) se(par fmt(2))) ///
legend label varlabels(_cons Constant)
   
/* Next, we want to add some things to the table, like R-squared, residual degrees of freedom. 
Stata has special names for each of these ancillary statistics, "r2" is the name for R-squared, 
"df_r" for residual degrees of freedom. 
You can get the names of these items from the ereturn list and from the help file. */

estout m1 m2 m3, cells(b(star fmt(3)) se(par fmt(2))) ///
legend label varlabels(_cons constant) ///
stats(r2 df_r)
   
/* We just need to clean up the lower part of the table giving each of the items a better label 
and adjusting the number of decimal places for each of the items. */

estout m1 m2 m3, cells(b(star fmt(3)) se(par fmt(2))) ///
legend label varlabels(_cons constant) ///
stats(r2 df_r, fmt(3 0) label(R-squared dfres))

estout m1 m2 m3 using hsb2_output.doc, cells(b(star fmt(3)) se(par fmt(2))) ///
legend label varlabels(_cons constant) ///
stats(r2 df_r, fmt(3 0) label(R-squared dfres)) replace

estout m1 m2 m3 using hsb2_output.xls, cells(b(star fmt(3)) se(par fmt(2))) ///
legend label varlabels(_cons constant) ///
stats(r2 df_r, fmt(3 0) label(R-squared dfres)) replace

*** outreg2

* [based on http://www2.fiu.edu/~tardanic/make.pdf and http://www2.fiu.edu/~tardanic/brianne.pdf
* http://www.stata.com/meeting/wcsug07/Rapid_Formation_article.pdf]

* To install outreg2
*"findit outreg2" or "ssc install outreg2"

* The syntax:

* outreg2 [varlist] [[estlist]] using filename [, options] 

/* where estlist refers the list of stored estimates encased with the square brackets [ ]. 
Both the varlist and estlist will take the wildcard abbreviation with asterisks. 
The options are roughly categorized as Main Options, Output Files, Decimals and Displays,
Auxiliary Statistics (associated with each estimated coefficient), 
and Ancillary Statistics (associated with each regression output). 
This section will focus on the core options and unique features that make it easy to use during research. */

/* outreg2 will report the latest regression output by default, or the list of stored estimates. 
The ancillary statistics from stored return can also be accessed using e( ) or addstat( ).

outreg2 will also report the usual statistics such as standard error with the asterisks 
for the levels of significance (1%, 5%, and 10%), t-statistics, p-values, the number of observations, R-squareds, 
and the number of groups in a panel estimation. 
Standarized beta coefficients, exponentially transformed coefficients (i.e. odds/risk ratios or hazard rate). 
The user can add their own column titles with ctitle and addnote options.

An immediate access to the produced table is provided in the browser view with see option. 
outreg2 also comes with automatically formatted number of significant digits, 
which  avoids the awkward displays assoicated with the fixed format. */

/* The basic plan for making a regression table with outreg2 is to run it after each regression. */

reg science math read female 
outreg2 using ols_science, replace // Click seeout in STATA results window. 
outreg2 using ols_science, word replace // Click ols_science.rtf.

/* After typing the outreg2 commands, click the blue link in Stata to see ('seeout') 
the table results in Stata's spreadsheet, or click the rtf link to see the Word formatted text. 
outreg2 has created txt and rtf files that contain the regression results. 
These files are located in the folder in which you are working. */

outreg2 using ols_science, replace seeout

* By specifying seeout option, the browser window automatically pops open.

outreg2 using ols_science, excel replace // Click ols_science.xml.

outreg2 using ols_science, alpha(0.001, 0.01, 0.05) symbol(***, **, *) adjr bdec(2) ///
ctitle(Science) addnote(Put your notes here) replace 

* adjr2 specifies that the adjusted R-squared be reported rather than the regular R-squared when available.
* bdec() specifies the number of decimals places of the regression coefficients
* ctitle adds column title

outreg2 using ols_science, ci replace 

* ci displays conf. intervals under the coefficent

outreg2 using ols_science, beta replace 

* beta displays normalized beta coefficients

outreg2 read female, replace // Displays only the specified explanatory variables.
 
reg science math read 
outreg2 using ols_science, replace 
reg science math read female prog 
outreg2 using ols_science, append // to display results of both models

*OR

reg science math read female prog 
estimates store Full
reg science math read 
estimates store Reduced
outreg2 [Full Reduced] using ols_science, replace 

* outreg2 as a suffix

outreg2, replace: reg science math read female prog 

reg science read write 
outreg2 using science, ctitle(Model) bdec(2) tdec(2) rdec(2) adec(2) alpha(.001, .01, .05) /// 
addstat(Adj. R-squared, e(r2_a)) addnote(Put your notes here.) word replace 

* adjr2 specifies that the adjusted R-squared be reported rather than the regular R-squared when available.
* ctitle adds column title
* bdec() specifies the number of decimals places of the regression coefficients
* tdec() -- for t-statistics
* rdec() -- for r-square
* adec() -- for addstat( ) contents


* ################
* ### 6.3 rego ###

*** rego
* [based on http://uni-leipzig.de/~rego/]

* To install rego
net from http://www.uni-leipzig.de/~rego/
net install rego

/* Purpose

"rego" uses results from regress and decomposes the share of explained variance (measured by R-squared) 
into contributions by indvidual regressor variables or groups of regressor variables.  
The former case is calculated as Owen value, the latter as Shapley value (for groups). 
In the special case that each group consists of only one regressor, both quantities coincide. 
If not suppressed by the noperc option, the contributions are displayed as percentages of overall R-squared.

The use of groups of regressor variables that belong to the same category 
(such as the variables that belong to a polynomial in age) reduces computational effort 
in comparison to classical Shapley decomposition without groupings.

Groups of regressors are specified with the help of the backslash ("\") symbol. 
It must be placed in the varlist after the last variable of each group.  
If no groups are defined, rego assumes that each regressor belongs to a group of its own 
and calculates the "traditional" Shapley value.

Instead of using the detail option after the comma, the user may also specify "(detail)" inside a variable group. 
This has the advantage that a decomposition is only carried out within groups of interest.

Caution: Computational effort increases exponentially in the number of groups and 
(if the detail option is specified) in the number of variables per group. 
The program will fall back to standard regression output and stop if the number of groups exceeds 12 
or the number of variables in a "detailed" group exceeds 12. 
The force option overrides this behavior.

REGO includes a bootstrap option to obtain confidence intervals for the decomposition results.

# Example

In the example below, REGO is used to decompose the R2 of a wage regression. 
The dependent variable is the logarithm of gross hourly earnings of male employees in Germany in the year 2006 
(data from the German Socio-Economic Panel).

The syntax uses the backslash (\) symbol to delimit groups of regressor variables. 
Without such groupings, REGO would compute Shapley values for the individual regressors, 
which would take very long due to the large number of variables; 
in fact, the force option would be required to tell REGO to start computing. 
The option (detail) requests the computation of within-group decomposition (Owen values). 
This would take a considerable amount of time if the number of variables in a group is large. */

/* xi: rego lwage sct01 sct01_edu edu (detail) \ exper exper2 (detail) \ tenure tenure2 (detail) ///
married \ i.firmsize \ i.industry \ i.state, vce(robust) */

/* xi expands terms containing categorical variables into indicator (also called dummy) variable 
sets by creating new variables and, 
in the second syntax (xi: any_stata_command), executes the specified command with the expanded terms.  
The dummy variables created are

        i.varname               creates dummies for categorical variable varname
		i.varname1*i.varname2   creates dummies for categorical variables varname1 and varname2: 
								all interactions and main effects */

*Examples from Stata help
		
use auto.dta, clear
describe

rego mpg weight length displ gear foreign
rego mpg weight length \ displ gear \ foreign, vce(robust) detail
rego mpg weight length \ displ gear \ foreign, vce(robust) detail noperc bsreps(2000) level(90)

* noperc - do not display Owen/Shapley values as percentages of overall R-squared
* bsreps - number of bootstrap replications
* level - confidence level, in %
 
use nhanes2f.dta, clear
describe

generate bmi = weight * (height/100)^(-2)
xi: rego bpsystol i.race \ age age2 \ i.region i.smsa \ diabetes \ bmi \ (detail) ///
albumin vitaminc zinc copper lead if female==1, vce(cluster location)
